@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2026 Zabbix SIA
+** Copyright 2001-2022 Zabbix SIA
 **
 ** Licensed under the Apache License, Version 2.0 (the "License");
 ** you may not use this file except in compliance with the License.
@@ -18,12 +18,37 @@
 package plugin
 
 import (
-	"golang.zabbix.com/plugin/mongodb/plugin/handlers"
-	"golang.zabbix.com/sdk/metric"
-	"golang.zabbix.com/sdk/plugin"
-	"golang.zabbix.com/sdk/uri"
+	"git.zabbix.com/ap/mongodb/plugin/handlers"
+	"git.zabbix.com/ap/plugin-support/metric"
+	"git.zabbix.com/ap/plugin-support/plugin"
+	"git.zabbix.com/ap/plugin-support/uri"
 )
 
+// handlerFunc defines an interface must be implemented by handlers.
+type handlerFunc func(s handlers.Session, params map[string]string) (res interface{}, err error)
+
+var metricHandlers = map[string]handlerFunc{
+	keyConfigDiscovery:      handlers.ConfigDiscoveryHandler,
+	keyCollectionStats:      handlers.CollectionStatsHandler,
+	keyCollectionsDiscovery: handlers.CollectionsDiscoveryHandler,
+	keyCollectionsUsage:     handlers.CollectionsUsageHandler,
+	keyConnPoolStats:        handlers.ConnPoolStatsHandler,
+	keyDatabaseStats:        handlers.DatabaseStatsHandler,
+	keyDatabasesDiscovery:   handlers.DatabasesDiscoveryHandler,
+	keyJumboChunks:          handlers.JumboChunksHandler,
+	keyOplogStats:           handlers.OplogStatsHandler,
+	keyPing:                 handlers.PingHandler,
+	keyReplSetConfig:        handlers.ReplSetConfigHandler,
+	keyReplSetStatus:        handlers.ReplSetStatusHandler,
+	keyServerStatus:         handlers.ServerStatusHandler,
+	keyShardsDiscovery:      handlers.ShardsDiscoveryHandler,
+}
+
+// getHandlerFunc returns a handlerFunc related to a given key.
+func getHandlerFunc(key string) handlerFunc {
+	return metricHandlers[key]
+}
+
 const (
 	keyConfigDiscovery      = "mongodb.cfg.discovery"
 	keyCollectionStats      = "mongodb.collection.stats"
@@ -39,196 +64,109 @@ const (
 	keyReplSetStatus        = "mongodb.rs.status"
 	keyServerStatus         = "mongodb.server.status"
 	keyShardsDiscovery      = "mongodb.sh.discovery"
-	keyVersion              = "mongodb.version"
-
-	uriParam        = "URI"
-	tlsConnectParam = "TLSConnect"
-	tlsCAParam      = "TLSCAFile"
-	tlsCertParam    = "TLSCertFile"
-	tlsKeyParam     = "TLSKeyFile"
 )
 
-var metricHandlers = map[string]handlerFunc{
-	keyCollectionStats:      handlers.CollectionStatsHandler,
-	keyCollectionsDiscovery: handlers.CollectionsDiscoveryHandler,
-	keyCollectionsUsage:     handlers.CollectionsUsageHandler,
-	keyConfigDiscovery:      handlers.ConfigDiscoveryHandler,
-	keyConnPoolStats:        handlers.ConnPoolStatsHandler,
-	keyDatabaseStats:        handlers.DatabaseStatsHandler,
-	keyDatabasesDiscovery:   handlers.DatabasesDiscoveryHandler,
-	keyJumboChunks:          handlers.JumboChunksHandler,
-	keyOplogStats:           handlers.OplogStatsHandler,
-	keyPing:                 handlers.PingHandler,
-	keyReplSetConfig:        handlers.ReplSetConfigHandler,
-	keyReplSetStatus:        handlers.ReplSetStatusHandler,
-	keyServerStatus:         handlers.ServerStatusHandler,
-	keyShardsDiscovery:      handlers.ShardsDiscoveryHandler,
-	keyVersion:              handlers.VersionHandler,
-}
-
 var (
-	paramURI = metric.NewConnParam(uriParam, "URI to connect or session name.").
+	paramURI = metric.NewConnParam("URI", "URI to connect or session name.").
 			WithDefault(handlers.UriDefaults.Scheme + "://localhost:" + handlers.UriDefaults.Port).WithSession().
 			WithValidator(uri.URIValidator{Defaults: handlers.UriDefaults, AllowedSchemes: []string{"tcp"}})
 	paramUser        = metric.NewConnParam("User", "MongoDB user.")
 	paramPassword    = metric.NewConnParam("Password", "User's password.")
 	paramDatabase    = metric.NewParam("Database", "Database name.").WithDefault("admin")
 	paramCollection  = metric.NewParam("Collection", "Collection name.").SetRequired()
-	paramTLSConnect  = metric.NewSessionOnlyParam(tlsConnectParam, "DB connection encryption type.").WithDefault("")
-	paramTLSCaFile   = metric.NewSessionOnlyParam(tlsCAParam, "TLS ca file path.").WithDefault("")
-	paramTLSCertFile = metric.NewSessionOnlyParam(tlsCertParam, "TLS cert file path.").WithDefault("")
-	paramTLSKeyFile  = metric.NewSessionOnlyParam(tlsKeyParam, "TLS key file path.").WithDefault("")
+	paramTLSConnect  = metric.NewSessionOnlyParam("TLSConnect", "DB connection encryption type.").WithDefault("")
+	paramTLSCaFile   = metric.NewSessionOnlyParam("TLSCAFile", "TLS ca file path.").WithDefault("")
+	paramTLSCertFile = metric.NewSessionOnlyParam("TLSCertFile", "TLS cert file path.").WithDefault("")
+	paramTLSKeyFile  = metric.NewSessionOnlyParam("TLSKeyFile", "TLS key file path.").WithDefault("")
 )
 
 var metrics = metric.MetricSet{
-	keyCollectionStats: metric.New(
-		"Returns a variety of storage statistics for a given collection.",
+	keyConfigDiscovery: metric.New("Returns a list of discovered config servers.",
+		[]*metric.Param{
+			paramURI, paramUser, paramPassword, paramTLSConnect, paramTLSCaFile, paramTLSCertFile, paramTLSKeyFile,
+		}, false),
+
+	keyCollectionStats: metric.New("Returns a variety of storage statistics for a given collection.",
 		[]*metric.Param{
 			paramURI, paramUser, paramPassword, paramDatabase, paramCollection,
 			paramTLSConnect, paramTLSCaFile, paramTLSCertFile, paramTLSKeyFile,
-		},
-		false,
-	),
+		}, false),
 
-	keyCollectionsDiscovery: metric.New(
-		"Returns a list of discovered collections.",
+	keyCollectionsDiscovery: metric.New("Returns a list of discovered collections.",
 		[]*metric.Param{
 			paramURI, paramUser, paramPassword,
 			paramTLSConnect, paramTLSCaFile, paramTLSCertFile, paramTLSKeyFile,
-		},
-		false,
-	),
+		}, false),
 
-	keyCollectionsUsage: metric.New(
-		"Returns usage statistics for collections.",
+	keyCollectionsUsage: metric.New("Returns usage statistics for collections.",
 		[]*metric.Param{
 			paramURI, paramUser, paramPassword,
 			paramTLSConnect, paramTLSCaFile, paramTLSCertFile, paramTLSKeyFile,
-		},
-		false,
-	),
+		}, false),
 
-	keyConfigDiscovery: metric.New(
-		"Returns a list of discovered config servers.",
-		[]*metric.Param{
-			paramURI, paramUser, paramPassword, paramTLSConnect, paramTLSCaFile, paramTLSCertFile, paramTLSKeyFile,
-		},
-		false,
-	),
-
-	keyConnPoolStats: metric.New(
-		"Returns information regarding the open outgoing connections from the "+
-			"current database instance to other members of the sharded cluster or replica set.",
+	keyConnPoolStats: metric.New("Returns information regarding the open outgoing connections from the "+
+		"current database instance to other members of the sharded cluster or replica set.",
 		[]*metric.Param{
 			paramURI, paramUser, paramPassword,
 			paramTLSConnect, paramTLSCaFile, paramTLSCertFile, paramTLSKeyFile,
-		},
-		false,
-	),
+		}, false),
 
-	keyDatabaseStats: metric.New(
-		"Returns statistics reflecting a given database system’s state.",
+	keyDatabaseStats: metric.New("Returns statistics reflecting a given database system’s state.",
 		[]*metric.Param{
 			paramURI, paramUser, paramPassword, paramDatabase,
 			paramTLSConnect, paramTLSCaFile, paramTLSCertFile, paramTLSKeyFile,
-		},
-		false,
-	),
+		}, false),
 
-	keyDatabasesDiscovery: metric.New(
-		"Returns a list of discovered databases.",
+	keyDatabasesDiscovery: metric.New("Returns a list of discovered databases.",
 		[]*metric.Param{
 			paramURI, paramUser, paramPassword,
 			paramTLSConnect, paramTLSCaFile, paramTLSCertFile, paramTLSKeyFile,
-		},
-		false,
-	),
+		}, false),
 
-	keyJumboChunks: metric.New(
-		"Returns count of jumbo chunks.",
+	keyJumboChunks: metric.New("Returns count of jumbo chunks.",
 		[]*metric.Param{
 			paramURI, paramUser, paramPassword,
 			paramTLSConnect, paramTLSCaFile, paramTLSCertFile, paramTLSKeyFile,
-		},
-		false,
-	),
+		}, false),
 
-	keyOplogStats: metric.New(
-		"Returns a status of the replica set, using data polled from the oplog.",
+	keyOplogStats: metric.New("Returns a status of the replica set, using data polled from the oplog.",
 		[]*metric.Param{
 			paramURI, paramUser, paramPassword,
 			paramTLSConnect, paramTLSCaFile, paramTLSCertFile, paramTLSKeyFile,
-		},
-		false,
-	),
+		}, false),
 
-	keyPing: metric.New(
-		"Test if connection is alive or not.",
+	keyPing: metric.New("Test if connection is alive or not.",
 		[]*metric.Param{
 			paramURI, paramUser, paramPassword,
 			paramTLSConnect, paramTLSCaFile, paramTLSCertFile, paramTLSKeyFile,
-		},
-		false,
-	),
+		}, false),
 
-	keyReplSetConfig: metric.New(
-		"Returns a current configuration of the replica set.",
+	keyReplSetConfig: metric.New("Returns a current configuration of the replica set.",
 		[]*metric.Param{
 			paramURI, paramUser, paramPassword,
 			paramTLSConnect, paramTLSCaFile, paramTLSCertFile, paramTLSKeyFile,
-		},
-		false,
-	),
+		}, false),
 
-	keyReplSetStatus: metric.New(
-		"Returns a replica set status from the point of view of the member "+
-			"where the method is run.",
+	keyReplSetStatus: metric.New("Returns a replica set status from the point of view of the member "+
+		"where the method is run.",
 		[]*metric.Param{
 			paramURI, paramUser, paramPassword,
 			paramTLSConnect, paramTLSCaFile, paramTLSCertFile, paramTLSKeyFile,
-		},
-		false,
-	),
+		}, false),
 
-	keyServerStatus: metric.New(
-		"Returns a database’s state.",
+	keyServerStatus: metric.New("Returns a database’s state.",
 		[]*metric.Param{
 			paramURI, paramUser, paramPassword,
 			paramTLSConnect, paramTLSCaFile, paramTLSCertFile, paramTLSKeyFile,
-		},
-		false,
-	),
+		}, false),
 
-	keyShardsDiscovery: metric.New(
-		"Returns a list of discovered shards present in the cluster.",
+	keyShardsDiscovery: metric.New("Returns a list of discovered shards present in the cluster.",
 		[]*metric.Param{
 			paramURI, paramUser, paramPassword,
 			paramTLSConnect, paramTLSCaFile, paramTLSCertFile, paramTLSKeyFile,
-		},
-		false,
-	),
-
-	keyVersion: metric.New(
-		"Returns database version.",
-		[]*metric.Param{
-			paramURI, paramUser, paramPassword,
-			paramTLSConnect, paramTLSCaFile, paramTLSCertFile, paramTLSKeyFile,
-		},
-		false,
-	),
+		}, false),
 }
 
-// handlerFunc defines an interface must be implemented by handlers.
-type handlerFunc func(s handlers.Session, params map[string]string) (res interface{}, err error)
-
 func init() {
-	err := plugin.RegisterMetrics(&Impl, Name, metrics.List()...)
-	if err != nil {
-		panic(err)
-	}
-}
-
-// getHandlerFunc returns a handlerFunc related to a given key.
-func getHandlerFunc(key string) handlerFunc {
-	return metricHandlers[key]
+	plugin.RegisterMetrics(&Impl, Name, metrics.List()...)
 }
