@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2026 Zabbix SIA
+** Copyright 2001-2022 Zabbix SIA
 **
 ** Licensed under the Apache License, Version 2.0 (the "License");
 ** you may not use this file except in compliance with the License.
@@ -20,11 +20,11 @@ package plugin
 import (
 	"time"
 
-	"golang.zabbix.com/plugin/mongodb/plugin/handlers"
-	"golang.zabbix.com/sdk/metric"
-	"golang.zabbix.com/sdk/plugin"
-	"golang.zabbix.com/sdk/uri"
-	"golang.zabbix.com/sdk/zbxerr"
+	"git.zabbix.com/ap/mongodb/plugin/handlers"
+	"git.zabbix.com/ap/plugin-support/plugin"
+	"git.zabbix.com/ap/plugin-support/tlsconfig"
+	"git.zabbix.com/ap/plugin-support/uri"
+	"git.zabbix.com/ap/plugin-support/zbxerr"
 )
 
 const (
@@ -32,8 +32,6 @@ const (
 	hkInterval = 10
 )
 
-var Impl Plugin
-
 // Plugin -
 type Plugin struct {
 	plugin.Base
@@ -41,13 +39,10 @@ type Plugin struct {
 	options PluginOptions
 }
 
-func (p *Plugin) Export(key string, rawParams []string, ctx plugin.ContextProvider) (result interface{}, err error) {
-	params, _, hc, err := metrics[key].EvalParams(rawParams, p.options.Sessions)
-	if err != nil {
-		return nil, err
-	}
+var Impl Plugin
 
-	err = metric.SetDefaults(params, hc, p.options.Default)
+func (p *Plugin) Export(key string, rawParams []string, ctx plugin.ContextProvider) (result interface{}, err error) {
+	params, _, err := metrics[key].EvalParams(rawParams, p.options.Sessions)
 	if err != nil {
 		return nil, err
 	}
@@ -57,12 +52,18 @@ func (p *Plugin) Export(key string, rawParams []string, ctx plugin.ContextProvid
 		return nil, err
 	}
 
+	details, err := tlsconfig.CreateDetails(params["sessionName"], params["TLSConnect"],
+		params["TLSCAFile"], params["TLSCertFile"], params["TLSKeyFile"], params["URI"])
+	if err != nil {
+		return nil, zbxerr.ErrorInvalidConfiguration.Wrap(err)
+	}
+
 	handleMetric := getHandlerFunc(key)
 	if handleMetric == nil {
 		return nil, zbxerr.ErrorUnsupportedMetric
 	}
 
-	conn, err := p.connMgr.GetConnection(*uri, params)
+	conn, err := p.connMgr.GetConnection(*uri, details)
 	if err != nil {
 		// Special logic of processing connection errors should be used if mongodb.ping is requested
 		// because it must return pingFailed if any error occurred.
@@ -94,7 +95,6 @@ func (p *Plugin) Start() {
 		time.Duration(p.options.KeepAlive)*time.Second,
 		time.Duration(p.options.Timeout)*time.Second,
 		hkInterval*time.Second,
-		p.Logger,
 	)
 }
 
